@@ -47,6 +47,7 @@ var a00250 =
     [ "PolyMeshT", "a00250.html#a2fdf6fd8d438200ff0c885b828affca4", null ],
     [ "~PolyMeshT", "a00250.html#a9c9a45cb7c87a1aaed9577210a68e527", null ],
     [ "add_vertex", "a00250.html#ac0577d7120881533e6e3af635382ba82", null ],
+    [ "add_vertex_dirty", "a00250.html#ad2b584d9b8cf0f168be8d536fc593ec0", null ],
     [ "calc_dihedral_angle", "a00250.html#a410f38155ec12c4409579f8346b4009c", null ],
     [ "calc_dihedral_angle", "a00250.html#a0c8076b4547614001d7f49960f8dd1ed", null ],
     [ "calc_dihedral_angle_fast", "a00250.html#a49dd0f24137854f97530779c58f1a964", null ],
@@ -76,6 +77,7 @@ var a00250 =
     [ "is_estimated_feature_edge", "a00250.html#a2f6f5dd7a243ce8b34233361f17131ff", null ],
     [ "new_vertex", "a00250.html#aee07d968ddfbb6376a7f7712ae1a73c4", null ],
     [ "new_vertex", "a00250.html#a77d36a90d4c207845cf1478aec56c283", null ],
+    [ "new_vertex_dirty", "a00250.html#a8787adda36a734b33fa578f9c50bb2f3", null ],
     [ "split", "a00250.html#af0bd67ac6c4c3fa8707191dcf28b7649", null ],
     [ "split", "a00250.html#a48712f39ad55c72ab48bf1127b6113bf", null ],
     [ "split", "a00250.html#ac198e4c43d5baf73b85557eaa48cc722", null ],
